# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: module_msg.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import util_msg_pb2 as util__msg__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='module_msg.proto',
  package='bess.pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x10module_msg.proto\x12\x07\x62\x65ss.pb\x1a\x0eutil_msg.proto\"\n\n\x08\x45mptyArg\"\x14\n\x12\x42PFCommandClearArg\"K\n\x17\x45xactMatchCommandAddArg\x12\x0c\n\x04gate\x18\x01 \x01(\x04\x12\"\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x12.bess.pb.FieldData\"@\n\x1a\x45xactMatchCommandDeleteArg\x12\"\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x12.bess.pb.FieldData\"\x1b\n\x19\x45xactMatchCommandClearArg\"2\n\"ExactMatchCommandSetDefaultGateArg\x12\x0c\n\x04gate\x18\x01 \x01(\x04\"*\n\x19\x46lowGenCommandSetBurstArg\x12\r\n\x05\x62urst\x18\x01 \x01(\x04\"G\n\x17HashLBCommandSetModeArg\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12\x1e\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x0e.bess.pb.Field\")\n\x18HashLBCommandSetGatesArg\x12\r\n\x05gates\x18\x01 \x03(\x03\"I\n\x15IPLookupCommandAddArg\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x12\n\nprefix_len\x18\x02 \x01(\x04\x12\x0c\n\x04gate\x18\x03 \x01(\x04\">\n\x18IPLookupCommandDeleteArg\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x12\n\nprefix_len\x18\x02 \x01(\x04\"\x19\n\x17IPLookupCommandClearArg\"u\n\x16L2ForwardCommandAddArg\x12\x36\n\x07\x65ntries\x18\x01 \x03(\x0b\x32%.bess.pb.L2ForwardCommandAddArg.Entry\x1a#\n\x05\x45ntry\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\x0c\n\x04gate\x18\x02 \x01(\x03\"*\n\x19L2ForwardCommandDeleteArg\x12\r\n\x05\x61\x64\x64rs\x18\x01 \x03(\t\"1\n!L2ForwardCommandSetDefaultGateArg\x12\x0c\n\x04gate\x18\x01 \x01(\x03\"*\n\x19L2ForwardCommandLookupArg\x12\r\n\x05\x61\x64\x64rs\x18\x01 \x03(\t\"/\n\x1eL2ForwardCommandLookupResponse\x12\r\n\x05gates\x18\x01 \x03(\x04\"N\n\x1bL2ForwardCommandPopulateArg\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x12\n\ngate_count\x18\x03 \x01(\x03\"e\n\x1bMeasureCommandGetSummaryArg\x12\r\n\x05\x63lear\x18\x01 \x01(\x08\x12\x1b\n\x13latency_percentiles\x18\x02 \x03(\x01\x12\x1a\n\x12jitter_percentiles\x18\x03 \x03(\x01\"\x88\x03\n MeasureCommandGetSummaryResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0f\n\x07packets\x18\x02 \x01(\x04\x12\x0c\n\x04\x62its\x18\x03 \x01(\x04\x12\x44\n\x07latency\x18\x04 \x01(\x0b\x32\x33.bess.pb.MeasureCommandGetSummaryResponse.Histogram\x12\x43\n\x06jitter\x18\x05 \x01(\x0b\x32\x33.bess.pb.MeasureCommandGetSummaryResponse.Histogram\x1a\xa6\x01\n\tHistogram\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x62ove_range\x18\x02 \x01(\x04\x12\x15\n\rresolution_ns\x18\x08 \x01(\x04\x12\x0e\n\x06min_ns\x18\x03 \x01(\x04\x12\x0e\n\x06\x61vg_ns\x18\x04 \x01(\x04\x12\x0e\n\x06max_ns\x18\x05 \x01(\x04\x12\x10\n\x08total_ns\x18\x06 \x01(\x04\x12\x1c\n\x14percentile_values_ns\x18\x07 \x03(\x04\"I\n\x06\x44RRArg\x12\x11\n\tnum_flows\x18\x01 \x01(\r\x12\x0f\n\x07quantum\x18\x02 \x01(\x04\x12\x1b\n\x13max_flow_queue_size\x18\x03 \x01(\r\" \n\rDRRQuantumArg\x12\x0f\n\x07quantum\x18\x01 \x01(\r\"0\n\x16\x44RRMaxFlowQueueSizeArg\x12\x16\n\x0emax_queue_size\x18\x01 \x01(\r\"*\n\x19PortIncCommandSetBurstArg\x12\r\n\x05\x62urst\x18\x01 \x01(\x04\"+\n\x1aQueueIncCommandSetBurstArg\x12\r\n\x05\x62urst\x18\x01 \x01(\x04\"(\n\x17QueueCommandSetBurstArg\x12\r\n\x05\x62urst\x18\x01 \x01(\x04\"&\n\x16QueueCommandSetSizeArg\x12\x0c\n\x04size\x18\x01 \x01(\x04\"\x1a\n\x18QueueCommandGetStatusArg\"q\n\x1dQueueCommandGetStatusResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x10\n\x08\x65nqueued\x18\x03 \x01(\x04\x12\x10\n\x08\x64\x65queued\x18\x04 \x01(\x04\x12\x0f\n\x07\x64ropped\x18\x05 \x01(\x04\"\x1d\n\x1bRandomUpdateCommandClearArg\"\x18\n\x16RewriteCommandClearArg\"\x17\n\x15UpdateCommandClearArg\"\x83\x01\n\x1aWildcardMatchCommandAddArg\x12\x0c\n\x04gate\x18\x01 \x01(\x04\x12\x10\n\x08priority\x18\x02 \x01(\x03\x12\"\n\x06values\x18\x03 \x03(\x0b\x32\x12.bess.pb.FieldData\x12!\n\x05masks\x18\x04 \x03(\x0b\x32\x12.bess.pb.FieldData\"f\n\x1dWildcardMatchCommandDeleteArg\x12\"\n\x06values\x18\x01 \x03(\x0b\x32\x12.bess.pb.FieldData\x12!\n\x05masks\x18\x02 \x03(\x0b\x32\x12.bess.pb.FieldData\"\x1e\n\x1cWildcardMatchCommandClearArg\"5\n%WildcardMatchCommandSetDefaultGateArg\x12\x0c\n\x04gate\x18\x01 \x01(\x04\"\x9c\x01\n\x06\x41\x43LArg\x12#\n\x05rules\x18\x01 \x03(\x0b\x32\x14.bess.pb.ACLArg.Rule\x1am\n\x04Rule\x12\x0e\n\x06src_ip\x18\x01 \x01(\t\x12\x0e\n\x06\x64st_ip\x18\x02 \x01(\t\x12\x10\n\x08src_port\x18\x03 \x01(\r\x12\x10\n\x08\x64st_port\x18\x04 \x01(\r\x12\x13\n\x0b\x65stablished\x18\x05 \x01(\x08\x12\x0c\n\x04\x64rop\x18\x06 \x01(\x08\"k\n\x06\x42PFArg\x12\'\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x16.bess.pb.BPFArg.Filter\x1a\x38\n\x06\x46ilter\x12\x10\n\x08priority\x18\x01 \x01(\x03\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0c\n\x04gate\x18\x03 \x01(\x03\"\x0b\n\tBufferArg\"Y\n\tBypassArg\x12\x18\n\x10\x63ycles_per_batch\x18\x01 \x01(\r\x12\x19\n\x11\x63ycles_per_packet\x18\x02 \x01(\r\x12\x17\n\x0f\x63ycles_per_byte\x18\x03 \x01(\r\"\x1b\n\x07\x44umpArg\x12\x10\n\x08interval\x18\x01 \x01(\x01\"\x0f\n\rEtherEncapArg\"R\n\rExactMatchArg\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.bess.pb.Field\x12!\n\x05masks\x18\x02 \x03(\x0b\x32\x12.bess.pb.FieldData\"Y\n\x10\x45xactMatchConfig\x12\x14\n\x0c\x64\x65\x66\x61ult_gate\x18\x01 \x01(\x04\x12/\n\x05rules\x18\x02 \x03(\x0b\x32 .bess.pb.ExactMatchCommandAddArg\"\xea\x01\n\nFlowGenArg\x12\x10\n\x08template\x18\x01 \x01(\x0c\x12\x0b\n\x03pps\x18\x02 \x01(\x01\x12\x11\n\tflow_rate\x18\x03 \x01(\x01\x12\x15\n\rflow_duration\x18\x04 \x01(\x01\x12\x0f\n\x07\x61rrival\x18\x05 \x01(\t\x12\x10\n\x08\x64uration\x18\x06 \x01(\t\x12\x14\n\x0cquick_rampup\x18\x07 \x01(\x08\x12\x14\n\x0cip_src_range\x18\x08 \x01(\r\x12\x14\n\x0cip_dst_range\x18\t \x01(\r\x12\x16\n\x0eport_src_range\x18\n \x01(\r\x12\x16\n\x0eport_dst_range\x18\x0b \x01(\r\" \n\x0fGenericDecapArg\x12\r\n\x05\x62ytes\x18\x01 \x01(\x04\"\xa9\x01\n\x0fGenericEncapArg\x12\x33\n\x06\x66ields\x18\x01 \x03(\x0b\x32#.bess.pb.GenericEncapArg.EncapField\x1a\x61\n\nEncapField\x12\x0c\n\x04size\x18\x01 \x01(\x04\x12\x13\n\tattribute\x18\x02 \x01(\tH\x00\x12#\n\x05value\x18\x03 \x01(\x0b\x32\x12.bess.pb.FieldDataH\x00\x42\x0b\n\tinsertion\"H\n\tHashLBArg\x12\r\n\x05gates\x18\x01 \x03(\x03\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\x1e\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x0e.bess.pb.Field\"\x0c\n\nIPEncapArg\"3\n\x0bIPLookupArg\x12\x11\n\tmax_rules\x18\x01 \x01(\r\x12\x11\n\tmax_tbl8s\x18\x02 \x01(\r\",\n\x0cL2ForwardArg\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x03\"\x0c\n\nMACSwapArg\"o\n\nMeasureArg\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\x1a\n\x12jitter_sample_prob\x18\x03 \x01(\x01\x12\x16\n\x0elatency_ns_max\x18\x04 \x01(\x04\x12\x1d\n\x15latency_ns_resolution\x18\x05 \x01(\r\"\n\n\x08MergeArg\"\xb7\x02\n\x0fMetadataTestArg\x12\x30\n\x04read\x18\x01 \x03(\x0b\x32\".bess.pb.MetadataTestArg.ReadEntry\x12\x32\n\x05write\x18\x02 \x03(\x0b\x32#.bess.pb.MetadataTestArg.WriteEntry\x12\x34\n\x06update\x18\x03 \x03(\x0b\x32$.bess.pb.MetadataTestArg.UpdateEntry\x1a+\n\tReadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a,\n\nWriteEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a-\n\x0bUpdateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xcd\x01\n\x06NATArg\x12\x32\n\text_addrs\x18\x01 \x03(\x0b\x32\x1f.bess.pb.NATArg.ExternalAddress\x1a:\n\tPortRange\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\r\x12\x0b\n\x03\x65nd\x18\x02 \x01(\r\x12\x11\n\tsuspended\x18\x03 \x01(\x08\x1aS\n\x0f\x45xternalAddress\x12\x10\n\x08\x65xt_addr\x18\x01 \x01(\t\x12.\n\x0bport_ranges\x18\x02 \x03(\x0b\x32\x19.bess.pb.NATArg.PortRange\"\xf4\x01\n\x0cStaticNATArg\x12\x35\n\x05pairs\x18\x01 \x03(\x0b\x32&.bess.pb.StaticNATArg.AddressRangePair\x1a*\n\x0c\x41\x64\x64ressRange\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x1a\x80\x01\n\x10\x41\x64\x64ressRangePair\x12\x35\n\tint_range\x18\x01 \x01(\x0b\x32\".bess.pb.StaticNATArg.AddressRange\x12\x35\n\text_range\x18\x02 \x01(\x0b\x32\".bess.pb.StaticNATArg.AddressRange\"\t\n\x07NoOpArg\",\n\nPortIncArg\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x10\n\x08prefetch\x18\x02 \x01(\x08\"\x1a\n\nPortOutArg\x12\x0c\n\x04port\x18\x01 \x01(\t\":\n\x0bQueueIncArg\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x0b\n\x03qid\x18\x02 \x01(\x04\x12\x10\n\x08prefetch\x18\x03 \x01(\x08\"(\n\x0bQueueOutArg\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x0b\n\x03qid\x18\x02 \x01(\x04\"@\n\x08QueueArg\x12\x0c\n\x04size\x18\x01 \x01(\x04\x12\x10\n\x08prefetch\x18\x02 \x01(\x08\x12\x14\n\x0c\x62\x61\x63kpressure\x18\x03 \x01(\x08\"2\n\x0eRandomSplitArg\x12\x11\n\tdrop_rate\x18\x01 \x01(\x01\x12\r\n\x05gates\x18\x02 \x03(\x03\"5\n RandomSplitCommandSetDroprateArg\x12\x11\n\tdrop_rate\x18\x01 \x01(\x01\".\n\x1dRandomSplitCommandSetGatesArg\x12\r\n\x05gates\x18\x01 \x03(\x03\"\x82\x01\n\x0fRandomUpdateArg\x12.\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1e.bess.pb.RandomUpdateArg.Field\x1a?\n\x05\x46ield\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x0b\n\x03min\x18\x03 \x01(\x04\x12\x0b\n\x03max\x18\x04 \x01(\x04\"\x1f\n\nRewriteArg\x12\x11\n\ttemplates\x18\x01 \x03(\x0c\"-\n\x1cRoundRobinCommandSetGatesArg\x12\r\n\x05gates\x18\x01 \x03(\x03\"+\n\x1bRoundRobinCommandSetModeArg\x12\x0c\n\x04mode\x18\x01 \x01(\t\",\n\rRoundRobinArg\x12\r\n\x05gates\x18\x01 \x03(\x03\x12\x0c\n\x04mode\x18\x02 \x01(\t\"\x1d\n\x0cReplicateArg\x12\r\n\x05gates\x18\x01 \x03(\x03\",\n\x1bReplicateCommandSetGatesArg\x12\r\n\x05gates\x18\x01 \x03(\x03\"\xd2\x01\n\x0eSetMetadataArg\x12\x30\n\x05\x61ttrs\x18\x01 \x03(\x0b\x32!.bess.pb.SetMetadataArg.Attribute\x1a\x8d\x01\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x13\n\tvalue_int\x18\x03 \x01(\x04H\x00\x12\x13\n\tvalue_bin\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\x0c\n\x04mask\x18\x06 \x01(\x0c\x12\x13\n\x0brshift_bits\x18\x07 \x01(\x05\x42\x07\n\x05value\"\t\n\x07SinkArg\")\n\x18SourceCommandSetBurstArg\x12\r\n\x05\x62urst\x18\x01 \x01(\x04\".\n\x1aSourceCommandSetPktSizeArg\x12\x10\n\x08pkt_size\x18\x01 \x01(\x04\"\x1d\n\tSourceArg\x12\x10\n\x08pkt_size\x18\x01 \x01(\x04\"G\n\x08SplitArg\x12\x0c\n\x04size\x18\x01 \x01(\x04\x12\x13\n\tattribute\x18\x02 \x01(\tH\x00\x12\x10\n\x06offset\x18\x03 \x01(\x03H\x00\x42\x06\n\x04type\"\x1e\n\x0cTimestampArg\x12\x0e\n\x06offset\x18\x01 \x01(\x04\"k\n\tUpdateArg\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.bess.pb.UpdateArg.Field\x1a\x34\n\x05\x46ield\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x01(\x04\"_\n\x0cUrlFilterArg\x12,\n\tblacklist\x18\x01 \x03(\x0b\x32\x19.bess.pb.UrlFilterArg.Url\x1a!\n\x03Url\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"?\n\x0fUrlFilterConfig\x12,\n\tblacklist\x18\x01 \x03(\x0b\x32\x19.bess.pb.UrlFilterArg.Url\"\x0c\n\nVLANPopArg\"\x1a\n\x0bVLANPushArg\x12\x0b\n\x03tci\x18\x01 \x01(\x04\"\x0e\n\x0cVLANSplitArg\"\x0f\n\rVXLANDecapArg\" \n\rVXLANEncapArg\x12\x0f\n\x07\x64stport\x18\x01 \x01(\x04\"2\n\x10WildcardMatchArg\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.bess.pb.Field\"_\n\x13WildcardMatchConfig\x12\x14\n\x0c\x64\x65\x66\x61ult_gate\x18\x01 \x01(\x04\x12\x32\n\x05rules\x18\x02 \x03(\x0b\x32#.bess.pb.WildcardMatchCommandAddArg\"/\n\x0f\x41rpResponderArg\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x10\n\x08mac_addr\x18\x02 \x01(\t\">\n\nMplsPopArg\x12\x19\n\x11remove_eth_header\x18\x01 \x01(\x08\x12\x15\n\rnext_eth_type\x18\x02 \x01(\r\"\x84\x01\n\x0eWorkerSplitArg\x12>\n\x0cworker_gates\x18\x01 \x03(\x0b\x32(.bess.pb.WorkerSplitArg.WorkerGatesEntry\x1a\x32\n\x10WorkerGatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x62\x06proto3'
  ,
  dependencies=[util__msg__pb2.DESCRIPTOR,])




_EMPTYARG = _descriptor.Descriptor(
  name='EmptyArg',
  full_name='bess.pb.EmptyArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=55,
)


_BPFCOMMANDCLEARARG = _descriptor.Descriptor(
  name='BPFCommandClearArg',
  full_name='bess.pb.BPFCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=77,
)


_EXACTMATCHCOMMANDADDARG = _descriptor.Descriptor(
  name='ExactMatchCommandAddArg',
  full_name='bess.pb.ExactMatchCommandAddArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.ExactMatchCommandAddArg.gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.ExactMatchCommandAddArg.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=154,
)


_EXACTMATCHCOMMANDDELETEARG = _descriptor.Descriptor(
  name='ExactMatchCommandDeleteArg',
  full_name='bess.pb.ExactMatchCommandDeleteArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.ExactMatchCommandDeleteArg.fields', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=220,
)


_EXACTMATCHCOMMANDCLEARARG = _descriptor.Descriptor(
  name='ExactMatchCommandClearArg',
  full_name='bess.pb.ExactMatchCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=249,
)


_EXACTMATCHCOMMANDSETDEFAULTGATEARG = _descriptor.Descriptor(
  name='ExactMatchCommandSetDefaultGateArg',
  full_name='bess.pb.ExactMatchCommandSetDefaultGateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.ExactMatchCommandSetDefaultGateArg.gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=301,
)


_FLOWGENCOMMANDSETBURSTARG = _descriptor.Descriptor(
  name='FlowGenCommandSetBurstArg',
  full_name='bess.pb.FlowGenCommandSetBurstArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='burst', full_name='bess.pb.FlowGenCommandSetBurstArg.burst', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=345,
)


_HASHLBCOMMANDSETMODEARG = _descriptor.Descriptor(
  name='HashLBCommandSetModeArg',
  full_name='bess.pb.HashLBCommandSetModeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='bess.pb.HashLBCommandSetModeArg.mode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.HashLBCommandSetModeArg.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=418,
)


_HASHLBCOMMANDSETGATESARG = _descriptor.Descriptor(
  name='HashLBCommandSetGatesArg',
  full_name='bess.pb.HashLBCommandSetGatesArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.HashLBCommandSetGatesArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=461,
)


_IPLOOKUPCOMMANDADDARG = _descriptor.Descriptor(
  name='IPLookupCommandAddArg',
  full_name='bess.pb.IPLookupCommandAddArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='bess.pb.IPLookupCommandAddArg.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix_len', full_name='bess.pb.IPLookupCommandAddArg.prefix_len', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.IPLookupCommandAddArg.gate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=536,
)


_IPLOOKUPCOMMANDDELETEARG = _descriptor.Descriptor(
  name='IPLookupCommandDeleteArg',
  full_name='bess.pb.IPLookupCommandDeleteArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='bess.pb.IPLookupCommandDeleteArg.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix_len', full_name='bess.pb.IPLookupCommandDeleteArg.prefix_len', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=600,
)


_IPLOOKUPCOMMANDCLEARARG = _descriptor.Descriptor(
  name='IPLookupCommandClearArg',
  full_name='bess.pb.IPLookupCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=627,
)


_L2FORWARDCOMMANDADDARG_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='bess.pb.L2ForwardCommandAddArg.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addr', full_name='bess.pb.L2ForwardCommandAddArg.Entry.addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.L2ForwardCommandAddArg.Entry.gate', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=746,
)

_L2FORWARDCOMMANDADDARG = _descriptor.Descriptor(
  name='L2ForwardCommandAddArg',
  full_name='bess.pb.L2ForwardCommandAddArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='bess.pb.L2ForwardCommandAddArg.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_L2FORWARDCOMMANDADDARG_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=746,
)


_L2FORWARDCOMMANDDELETEARG = _descriptor.Descriptor(
  name='L2ForwardCommandDeleteArg',
  full_name='bess.pb.L2ForwardCommandDeleteArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addrs', full_name='bess.pb.L2ForwardCommandDeleteArg.addrs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=790,
)


_L2FORWARDCOMMANDSETDEFAULTGATEARG = _descriptor.Descriptor(
  name='L2ForwardCommandSetDefaultGateArg',
  full_name='bess.pb.L2ForwardCommandSetDefaultGateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.L2ForwardCommandSetDefaultGateArg.gate', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=841,
)


_L2FORWARDCOMMANDLOOKUPARG = _descriptor.Descriptor(
  name='L2ForwardCommandLookupArg',
  full_name='bess.pb.L2ForwardCommandLookupArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='addrs', full_name='bess.pb.L2ForwardCommandLookupArg.addrs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=885,
)


_L2FORWARDCOMMANDLOOKUPRESPONSE = _descriptor.Descriptor(
  name='L2ForwardCommandLookupResponse',
  full_name='bess.pb.L2ForwardCommandLookupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.L2ForwardCommandLookupResponse.gates', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=934,
)


_L2FORWARDCOMMANDPOPULATEARG = _descriptor.Descriptor(
  name='L2ForwardCommandPopulateArg',
  full_name='bess.pb.L2ForwardCommandPopulateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='bess.pb.L2ForwardCommandPopulateArg.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='bess.pb.L2ForwardCommandPopulateArg.count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gate_count', full_name='bess.pb.L2ForwardCommandPopulateArg.gate_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=1014,
)


_MEASURECOMMANDGETSUMMARYARG = _descriptor.Descriptor(
  name='MeasureCommandGetSummaryArg',
  full_name='bess.pb.MeasureCommandGetSummaryArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear', full_name='bess.pb.MeasureCommandGetSummaryArg.clear', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_percentiles', full_name='bess.pb.MeasureCommandGetSummaryArg.latency_percentiles', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jitter_percentiles', full_name='bess.pb.MeasureCommandGetSummaryArg.jitter_percentiles', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1117,
)


_MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM = _descriptor.Descriptor(
  name='Histogram',
  full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='above_range', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.above_range', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resolution_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.resolution_ns', index=2,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.min_ns', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.avg_ns', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.max_ns', index=5,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.total_ns', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percentile_values_ns', full_name='bess.pb.MeasureCommandGetSummaryResponse.Histogram.percentile_values_ns', index=7,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1512,
)

_MEASURECOMMANDGETSUMMARYRESPONSE = _descriptor.Descriptor(
  name='MeasureCommandGetSummaryResponse',
  full_name='bess.pb.MeasureCommandGetSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='bess.pb.MeasureCommandGetSummaryResponse.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packets', full_name='bess.pb.MeasureCommandGetSummaryResponse.packets', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bits', full_name='bess.pb.MeasureCommandGetSummaryResponse.bits', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency', full_name='bess.pb.MeasureCommandGetSummaryResponse.latency', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jitter', full_name='bess.pb.MeasureCommandGetSummaryResponse.jitter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1512,
)


_DRRARG = _descriptor.Descriptor(
  name='DRRArg',
  full_name='bess.pb.DRRArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_flows', full_name='bess.pb.DRRArg.num_flows', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantum', full_name='bess.pb.DRRArg.quantum', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_flow_queue_size', full_name='bess.pb.DRRArg.max_flow_queue_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1587,
)


_DRRQUANTUMARG = _descriptor.Descriptor(
  name='DRRQuantumArg',
  full_name='bess.pb.DRRQuantumArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantum', full_name='bess.pb.DRRQuantumArg.quantum', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1589,
  serialized_end=1621,
)


_DRRMAXFLOWQUEUESIZEARG = _descriptor.Descriptor(
  name='DRRMaxFlowQueueSizeArg',
  full_name='bess.pb.DRRMaxFlowQueueSizeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_queue_size', full_name='bess.pb.DRRMaxFlowQueueSizeArg.max_queue_size', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1623,
  serialized_end=1671,
)


_PORTINCCOMMANDSETBURSTARG = _descriptor.Descriptor(
  name='PortIncCommandSetBurstArg',
  full_name='bess.pb.PortIncCommandSetBurstArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='burst', full_name='bess.pb.PortIncCommandSetBurstArg.burst', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1715,
)


_QUEUEINCCOMMANDSETBURSTARG = _descriptor.Descriptor(
  name='QueueIncCommandSetBurstArg',
  full_name='bess.pb.QueueIncCommandSetBurstArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='burst', full_name='bess.pb.QueueIncCommandSetBurstArg.burst', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1717,
  serialized_end=1760,
)


_QUEUECOMMANDSETBURSTARG = _descriptor.Descriptor(
  name='QueueCommandSetBurstArg',
  full_name='bess.pb.QueueCommandSetBurstArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='burst', full_name='bess.pb.QueueCommandSetBurstArg.burst', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1762,
  serialized_end=1802,
)


_QUEUECOMMANDSETSIZEARG = _descriptor.Descriptor(
  name='QueueCommandSetSizeArg',
  full_name='bess.pb.QueueCommandSetSizeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.QueueCommandSetSizeArg.size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1842,
)


_QUEUECOMMANDGETSTATUSARG = _descriptor.Descriptor(
  name='QueueCommandGetStatusArg',
  full_name='bess.pb.QueueCommandGetStatusArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1870,
)


_QUEUECOMMANDGETSTATUSRESPONSE = _descriptor.Descriptor(
  name='QueueCommandGetStatusResponse',
  full_name='bess.pb.QueueCommandGetStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='bess.pb.QueueCommandGetStatusResponse.count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.QueueCommandGetStatusResponse.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enqueued', full_name='bess.pb.QueueCommandGetStatusResponse.enqueued', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dequeued', full_name='bess.pb.QueueCommandGetStatusResponse.dequeued', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dropped', full_name='bess.pb.QueueCommandGetStatusResponse.dropped', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1872,
  serialized_end=1985,
)


_RANDOMUPDATECOMMANDCLEARARG = _descriptor.Descriptor(
  name='RandomUpdateCommandClearArg',
  full_name='bess.pb.RandomUpdateCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2016,
)


_REWRITECOMMANDCLEARARG = _descriptor.Descriptor(
  name='RewriteCommandClearArg',
  full_name='bess.pb.RewriteCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2042,
)


_UPDATECOMMANDCLEARARG = _descriptor.Descriptor(
  name='UpdateCommandClearArg',
  full_name='bess.pb.UpdateCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2044,
  serialized_end=2067,
)


_WILDCARDMATCHCOMMANDADDARG = _descriptor.Descriptor(
  name='WildcardMatchCommandAddArg',
  full_name='bess.pb.WildcardMatchCommandAddArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.WildcardMatchCommandAddArg.gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='bess.pb.WildcardMatchCommandAddArg.priority', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='bess.pb.WildcardMatchCommandAddArg.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masks', full_name='bess.pb.WildcardMatchCommandAddArg.masks', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2070,
  serialized_end=2201,
)


_WILDCARDMATCHCOMMANDDELETEARG = _descriptor.Descriptor(
  name='WildcardMatchCommandDeleteArg',
  full_name='bess.pb.WildcardMatchCommandDeleteArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='bess.pb.WildcardMatchCommandDeleteArg.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masks', full_name='bess.pb.WildcardMatchCommandDeleteArg.masks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2305,
)


_WILDCARDMATCHCOMMANDCLEARARG = _descriptor.Descriptor(
  name='WildcardMatchCommandClearArg',
  full_name='bess.pb.WildcardMatchCommandClearArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2307,
  serialized_end=2337,
)


_WILDCARDMATCHCOMMANDSETDEFAULTGATEARG = _descriptor.Descriptor(
  name='WildcardMatchCommandSetDefaultGateArg',
  full_name='bess.pb.WildcardMatchCommandSetDefaultGateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.WildcardMatchCommandSetDefaultGateArg.gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2339,
  serialized_end=2392,
)


_ACLARG_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='bess.pb.ACLArg.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_ip', full_name='bess.pb.ACLArg.Rule.src_ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='bess.pb.ACLArg.Rule.dst_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='bess.pb.ACLArg.Rule.src_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='bess.pb.ACLArg.Rule.dst_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='established', full_name='bess.pb.ACLArg.Rule.established', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop', full_name='bess.pb.ACLArg.Rule.drop', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2442,
  serialized_end=2551,
)

_ACLARG = _descriptor.Descriptor(
  name='ACLArg',
  full_name='bess.pb.ACLArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='bess.pb.ACLArg.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACLARG_RULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2395,
  serialized_end=2551,
)


_BPFARG_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='bess.pb.BPFArg.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='bess.pb.BPFArg.Filter.priority', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='bess.pb.BPFArg.Filter.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gate', full_name='bess.pb.BPFArg.Filter.gate', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2604,
  serialized_end=2660,
)

_BPFARG = _descriptor.Descriptor(
  name='BPFArg',
  full_name='bess.pb.BPFArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='bess.pb.BPFArg.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BPFARG_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2553,
  serialized_end=2660,
)


_BUFFERARG = _descriptor.Descriptor(
  name='BufferArg',
  full_name='bess.pb.BufferArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2673,
)


_BYPASSARG = _descriptor.Descriptor(
  name='BypassArg',
  full_name='bess.pb.BypassArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cycles_per_batch', full_name='bess.pb.BypassArg.cycles_per_batch', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cycles_per_packet', full_name='bess.pb.BypassArg.cycles_per_packet', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cycles_per_byte', full_name='bess.pb.BypassArg.cycles_per_byte', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2675,
  serialized_end=2764,
)


_DUMPARG = _descriptor.Descriptor(
  name='DumpArg',
  full_name='bess.pb.DumpArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='bess.pb.DumpArg.interval', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=2793,
)


_ETHERENCAPARG = _descriptor.Descriptor(
  name='EtherEncapArg',
  full_name='bess.pb.EtherEncapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2810,
)


_EXACTMATCHARG = _descriptor.Descriptor(
  name='ExactMatchArg',
  full_name='bess.pb.ExactMatchArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.ExactMatchArg.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masks', full_name='bess.pb.ExactMatchArg.masks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2812,
  serialized_end=2894,
)


_EXACTMATCHCONFIG = _descriptor.Descriptor(
  name='ExactMatchConfig',
  full_name='bess.pb.ExactMatchConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_gate', full_name='bess.pb.ExactMatchConfig.default_gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='bess.pb.ExactMatchConfig.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2896,
  serialized_end=2985,
)


_FLOWGENARG = _descriptor.Descriptor(
  name='FlowGenArg',
  full_name='bess.pb.FlowGenArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='bess.pb.FlowGenArg.template', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pps', full_name='bess.pb.FlowGenArg.pps', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_rate', full_name='bess.pb.FlowGenArg.flow_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_duration', full_name='bess.pb.FlowGenArg.flow_duration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrival', full_name='bess.pb.FlowGenArg.arrival', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='bess.pb.FlowGenArg.duration', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quick_rampup', full_name='bess.pb.FlowGenArg.quick_rampup', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_src_range', full_name='bess.pb.FlowGenArg.ip_src_range', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_dst_range', full_name='bess.pb.FlowGenArg.ip_dst_range', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_src_range', full_name='bess.pb.FlowGenArg.port_src_range', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_dst_range', full_name='bess.pb.FlowGenArg.port_dst_range', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2988,
  serialized_end=3222,
)


_GENERICDECAPARG = _descriptor.Descriptor(
  name='GenericDecapArg',
  full_name='bess.pb.GenericDecapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes', full_name='bess.pb.GenericDecapArg.bytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3224,
  serialized_end=3256,
)


_GENERICENCAPARG_ENCAPFIELD = _descriptor.Descriptor(
  name='EncapField',
  full_name='bess.pb.GenericEncapArg.EncapField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.GenericEncapArg.EncapField.size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='bess.pb.GenericEncapArg.EncapField.attribute', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.GenericEncapArg.EncapField.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='insertion', full_name='bess.pb.GenericEncapArg.EncapField.insertion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3331,
  serialized_end=3428,
)

_GENERICENCAPARG = _descriptor.Descriptor(
  name='GenericEncapArg',
  full_name='bess.pb.GenericEncapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.GenericEncapArg.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GENERICENCAPARG_ENCAPFIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3259,
  serialized_end=3428,
)


_HASHLBARG = _descriptor.Descriptor(
  name='HashLBArg',
  full_name='bess.pb.HashLBArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.HashLBArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='bess.pb.HashLBArg.mode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.HashLBArg.fields', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3430,
  serialized_end=3502,
)


_IPENCAPARG = _descriptor.Descriptor(
  name='IPEncapArg',
  full_name='bess.pb.IPEncapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3504,
  serialized_end=3516,
)


_IPLOOKUPARG = _descriptor.Descriptor(
  name='IPLookupArg',
  full_name='bess.pb.IPLookupArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_rules', full_name='bess.pb.IPLookupArg.max_rules', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_tbl8s', full_name='bess.pb.IPLookupArg.max_tbl8s', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3518,
  serialized_end=3569,
)


_L2FORWARDARG = _descriptor.Descriptor(
  name='L2ForwardArg',
  full_name='bess.pb.L2ForwardArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.L2ForwardArg.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='bess.pb.L2ForwardArg.bucket', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3571,
  serialized_end=3615,
)


_MACSWAPARG = _descriptor.Descriptor(
  name='MACSwapArg',
  full_name='bess.pb.MACSwapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3617,
  serialized_end=3629,
)


_MEASUREARG = _descriptor.Descriptor(
  name='MeasureArg',
  full_name='bess.pb.MeasureArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.MeasureArg.offset', index=0,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jitter_sample_prob', full_name='bess.pb.MeasureArg.jitter_sample_prob', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_ns_max', full_name='bess.pb.MeasureArg.latency_ns_max', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_ns_resolution', full_name='bess.pb.MeasureArg.latency_ns_resolution', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3631,
  serialized_end=3742,
)


_MERGEARG = _descriptor.Descriptor(
  name='MergeArg',
  full_name='bess.pb.MergeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3744,
  serialized_end=3754,
)


_METADATATESTARG_READENTRY = _descriptor.Descriptor(
  name='ReadEntry',
  full_name='bess.pb.MetadataTestArg.ReadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.MetadataTestArg.ReadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.MetadataTestArg.ReadEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3932,
  serialized_end=3975,
)

_METADATATESTARG_WRITEENTRY = _descriptor.Descriptor(
  name='WriteEntry',
  full_name='bess.pb.MetadataTestArg.WriteEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.MetadataTestArg.WriteEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.MetadataTestArg.WriteEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3977,
  serialized_end=4021,
)

_METADATATESTARG_UPDATEENTRY = _descriptor.Descriptor(
  name='UpdateEntry',
  full_name='bess.pb.MetadataTestArg.UpdateEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.MetadataTestArg.UpdateEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.MetadataTestArg.UpdateEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4023,
  serialized_end=4068,
)

_METADATATESTARG = _descriptor.Descriptor(
  name='MetadataTestArg',
  full_name='bess.pb.MetadataTestArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read', full_name='bess.pb.MetadataTestArg.read', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write', full_name='bess.pb.MetadataTestArg.write', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='bess.pb.MetadataTestArg.update', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METADATATESTARG_READENTRY, _METADATATESTARG_WRITEENTRY, _METADATATESTARG_UPDATEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3757,
  serialized_end=4068,
)


_NATARG_PORTRANGE = _descriptor.Descriptor(
  name='PortRange',
  full_name='bess.pb.NATArg.PortRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='bess.pb.NATArg.PortRange.begin', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='bess.pb.NATArg.PortRange.end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspended', full_name='bess.pb.NATArg.PortRange.suspended', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4133,
  serialized_end=4191,
)

_NATARG_EXTERNALADDRESS = _descriptor.Descriptor(
  name='ExternalAddress',
  full_name='bess.pb.NATArg.ExternalAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ext_addr', full_name='bess.pb.NATArg.ExternalAddress.ext_addr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_ranges', full_name='bess.pb.NATArg.ExternalAddress.port_ranges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4193,
  serialized_end=4276,
)

_NATARG = _descriptor.Descriptor(
  name='NATArg',
  full_name='bess.pb.NATArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ext_addrs', full_name='bess.pb.NATArg.ext_addrs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_NATARG_PORTRANGE, _NATARG_EXTERNALADDRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4071,
  serialized_end=4276,
)


_STATICNATARG_ADDRESSRANGE = _descriptor.Descriptor(
  name='AddressRange',
  full_name='bess.pb.StaticNATArg.AddressRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='bess.pb.StaticNATArg.AddressRange.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='bess.pb.StaticNATArg.AddressRange.end', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4350,
  serialized_end=4392,
)

_STATICNATARG_ADDRESSRANGEPAIR = _descriptor.Descriptor(
  name='AddressRangePair',
  full_name='bess.pb.StaticNATArg.AddressRangePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_range', full_name='bess.pb.StaticNATArg.AddressRangePair.int_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_range', full_name='bess.pb.StaticNATArg.AddressRangePair.ext_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4395,
  serialized_end=4523,
)

_STATICNATARG = _descriptor.Descriptor(
  name='StaticNATArg',
  full_name='bess.pb.StaticNATArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='bess.pb.StaticNATArg.pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATICNATARG_ADDRESSRANGE, _STATICNATARG_ADDRESSRANGEPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4279,
  serialized_end=4523,
)


_NOOPARG = _descriptor.Descriptor(
  name='NoOpArg',
  full_name='bess.pb.NoOpArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4525,
  serialized_end=4534,
)


_PORTINCARG = _descriptor.Descriptor(
  name='PortIncArg',
  full_name='bess.pb.PortIncArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='bess.pb.PortIncArg.port', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefetch', full_name='bess.pb.PortIncArg.prefetch', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4580,
)


_PORTOUTARG = _descriptor.Descriptor(
  name='PortOutArg',
  full_name='bess.pb.PortOutArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='bess.pb.PortOutArg.port', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4582,
  serialized_end=4608,
)


_QUEUEINCARG = _descriptor.Descriptor(
  name='QueueIncArg',
  full_name='bess.pb.QueueIncArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='bess.pb.QueueIncArg.port', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qid', full_name='bess.pb.QueueIncArg.qid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefetch', full_name='bess.pb.QueueIncArg.prefetch', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4610,
  serialized_end=4668,
)


_QUEUEOUTARG = _descriptor.Descriptor(
  name='QueueOutArg',
  full_name='bess.pb.QueueOutArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='bess.pb.QueueOutArg.port', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qid', full_name='bess.pb.QueueOutArg.qid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4670,
  serialized_end=4710,
)


_QUEUEARG = _descriptor.Descriptor(
  name='QueueArg',
  full_name='bess.pb.QueueArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.QueueArg.size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefetch', full_name='bess.pb.QueueArg.prefetch', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backpressure', full_name='bess.pb.QueueArg.backpressure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4712,
  serialized_end=4776,
)


_RANDOMSPLITARG = _descriptor.Descriptor(
  name='RandomSplitArg',
  full_name='bess.pb.RandomSplitArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_rate', full_name='bess.pb.RandomSplitArg.drop_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.RandomSplitArg.gates', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4778,
  serialized_end=4828,
)


_RANDOMSPLITCOMMANDSETDROPRATEARG = _descriptor.Descriptor(
  name='RandomSplitCommandSetDroprateArg',
  full_name='bess.pb.RandomSplitCommandSetDroprateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_rate', full_name='bess.pb.RandomSplitCommandSetDroprateArg.drop_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4830,
  serialized_end=4883,
)


_RANDOMSPLITCOMMANDSETGATESARG = _descriptor.Descriptor(
  name='RandomSplitCommandSetGatesArg',
  full_name='bess.pb.RandomSplitCommandSetGatesArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.RandomSplitCommandSetGatesArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4885,
  serialized_end=4931,
)


_RANDOMUPDATEARG_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='bess.pb.RandomUpdateArg.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.RandomUpdateArg.Field.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.RandomUpdateArg.Field.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='bess.pb.RandomUpdateArg.Field.min', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='bess.pb.RandomUpdateArg.Field.max', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5001,
  serialized_end=5064,
)

_RANDOMUPDATEARG = _descriptor.Descriptor(
  name='RandomUpdateArg',
  full_name='bess.pb.RandomUpdateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.RandomUpdateArg.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RANDOMUPDATEARG_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4934,
  serialized_end=5064,
)


_REWRITEARG = _descriptor.Descriptor(
  name='RewriteArg',
  full_name='bess.pb.RewriteArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templates', full_name='bess.pb.RewriteArg.templates', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5066,
  serialized_end=5097,
)


_ROUNDROBINCOMMANDSETGATESARG = _descriptor.Descriptor(
  name='RoundRobinCommandSetGatesArg',
  full_name='bess.pb.RoundRobinCommandSetGatesArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.RoundRobinCommandSetGatesArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5099,
  serialized_end=5144,
)


_ROUNDROBINCOMMANDSETMODEARG = _descriptor.Descriptor(
  name='RoundRobinCommandSetModeArg',
  full_name='bess.pb.RoundRobinCommandSetModeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='bess.pb.RoundRobinCommandSetModeArg.mode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5146,
  serialized_end=5189,
)


_ROUNDROBINARG = _descriptor.Descriptor(
  name='RoundRobinArg',
  full_name='bess.pb.RoundRobinArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.RoundRobinArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='bess.pb.RoundRobinArg.mode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5191,
  serialized_end=5235,
)


_REPLICATEARG = _descriptor.Descriptor(
  name='ReplicateArg',
  full_name='bess.pb.ReplicateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.ReplicateArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5237,
  serialized_end=5266,
)


_REPLICATECOMMANDSETGATESARG = _descriptor.Descriptor(
  name='ReplicateCommandSetGatesArg',
  full_name='bess.pb.ReplicateCommandSetGatesArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gates', full_name='bess.pb.ReplicateCommandSetGatesArg.gates', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5268,
  serialized_end=5312,
)


_SETMETADATAARG_ATTRIBUTE = _descriptor.Descriptor(
  name='Attribute',
  full_name='bess.pb.SetMetadataArg.Attribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bess.pb.SetMetadataArg.Attribute.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.SetMetadataArg.Attribute.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_int', full_name='bess.pb.SetMetadataArg.Attribute.value_int', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_bin', full_name='bess.pb.SetMetadataArg.Attribute.value_bin', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.SetMetadataArg.Attribute.offset', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='bess.pb.SetMetadataArg.Attribute.mask', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rshift_bits', full_name='bess.pb.SetMetadataArg.Attribute.rshift_bits', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='bess.pb.SetMetadataArg.Attribute.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5384,
  serialized_end=5525,
)

_SETMETADATAARG = _descriptor.Descriptor(
  name='SetMetadataArg',
  full_name='bess.pb.SetMetadataArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attrs', full_name='bess.pb.SetMetadataArg.attrs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SETMETADATAARG_ATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5315,
  serialized_end=5525,
)


_SINKARG = _descriptor.Descriptor(
  name='SinkArg',
  full_name='bess.pb.SinkArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5527,
  serialized_end=5536,
)


_SOURCECOMMANDSETBURSTARG = _descriptor.Descriptor(
  name='SourceCommandSetBurstArg',
  full_name='bess.pb.SourceCommandSetBurstArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='burst', full_name='bess.pb.SourceCommandSetBurstArg.burst', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5538,
  serialized_end=5579,
)


_SOURCECOMMANDSETPKTSIZEARG = _descriptor.Descriptor(
  name='SourceCommandSetPktSizeArg',
  full_name='bess.pb.SourceCommandSetPktSizeArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkt_size', full_name='bess.pb.SourceCommandSetPktSizeArg.pkt_size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5581,
  serialized_end=5627,
)


_SOURCEARG = _descriptor.Descriptor(
  name='SourceArg',
  full_name='bess.pb.SourceArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pkt_size', full_name='bess.pb.SourceArg.pkt_size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5629,
  serialized_end=5658,
)


_SPLITARG = _descriptor.Descriptor(
  name='SplitArg',
  full_name='bess.pb.SplitArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.SplitArg.size', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='bess.pb.SplitArg.attribute', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.SplitArg.offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='bess.pb.SplitArg.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5660,
  serialized_end=5731,
)


_TIMESTAMPARG = _descriptor.Descriptor(
  name='TimestampArg',
  full_name='bess.pb.TimestampArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.TimestampArg.offset', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5733,
  serialized_end=5763,
)


_UPDATEARG_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='bess.pb.UpdateArg.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='bess.pb.UpdateArg.Field.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='bess.pb.UpdateArg.Field.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.UpdateArg.Field.value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5820,
  serialized_end=5872,
)

_UPDATEARG = _descriptor.Descriptor(
  name='UpdateArg',
  full_name='bess.pb.UpdateArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.UpdateArg.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEARG_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5765,
  serialized_end=5872,
)


_URLFILTERARG_URL = _descriptor.Descriptor(
  name='Url',
  full_name='bess.pb.UrlFilterArg.Url',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='bess.pb.UrlFilterArg.Url.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='bess.pb.UrlFilterArg.Url.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5936,
  serialized_end=5969,
)

_URLFILTERARG = _descriptor.Descriptor(
  name='UrlFilterArg',
  full_name='bess.pb.UrlFilterArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blacklist', full_name='bess.pb.UrlFilterArg.blacklist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_URLFILTERARG_URL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5874,
  serialized_end=5969,
)


_URLFILTERCONFIG = _descriptor.Descriptor(
  name='UrlFilterConfig',
  full_name='bess.pb.UrlFilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blacklist', full_name='bess.pb.UrlFilterConfig.blacklist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5971,
  serialized_end=6034,
)


_VLANPOPARG = _descriptor.Descriptor(
  name='VLANPopArg',
  full_name='bess.pb.VLANPopArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6036,
  serialized_end=6048,
)


_VLANPUSHARG = _descriptor.Descriptor(
  name='VLANPushArg',
  full_name='bess.pb.VLANPushArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tci', full_name='bess.pb.VLANPushArg.tci', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6050,
  serialized_end=6076,
)


_VLANSPLITARG = _descriptor.Descriptor(
  name='VLANSplitArg',
  full_name='bess.pb.VLANSplitArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6078,
  serialized_end=6092,
)


_VXLANDECAPARG = _descriptor.Descriptor(
  name='VXLANDecapArg',
  full_name='bess.pb.VXLANDecapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6094,
  serialized_end=6109,
)


_VXLANENCAPARG = _descriptor.Descriptor(
  name='VXLANEncapArg',
  full_name='bess.pb.VXLANEncapArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dstport', full_name='bess.pb.VXLANEncapArg.dstport', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6111,
  serialized_end=6143,
)


_WILDCARDMATCHARG = _descriptor.Descriptor(
  name='WildcardMatchArg',
  full_name='bess.pb.WildcardMatchArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='bess.pb.WildcardMatchArg.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6145,
  serialized_end=6195,
)


_WILDCARDMATCHCONFIG = _descriptor.Descriptor(
  name='WildcardMatchConfig',
  full_name='bess.pb.WildcardMatchConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_gate', full_name='bess.pb.WildcardMatchConfig.default_gate', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='bess.pb.WildcardMatchConfig.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6197,
  serialized_end=6292,
)


_ARPRESPONDERARG = _descriptor.Descriptor(
  name='ArpResponderArg',
  full_name='bess.pb.ArpResponderArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='bess.pb.ArpResponderArg.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mac_addr', full_name='bess.pb.ArpResponderArg.mac_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6294,
  serialized_end=6341,
)


_MPLSPOPARG = _descriptor.Descriptor(
  name='MplsPopArg',
  full_name='bess.pb.MplsPopArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remove_eth_header', full_name='bess.pb.MplsPopArg.remove_eth_header', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_eth_type', full_name='bess.pb.MplsPopArg.next_eth_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6343,
  serialized_end=6405,
)


_WORKERSPLITARG_WORKERGATESENTRY = _descriptor.Descriptor(
  name='WorkerGatesEntry',
  full_name='bess.pb.WorkerSplitArg.WorkerGatesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bess.pb.WorkerSplitArg.WorkerGatesEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bess.pb.WorkerSplitArg.WorkerGatesEntry.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6490,
  serialized_end=6540,
)

_WORKERSPLITARG = _descriptor.Descriptor(
  name='WorkerSplitArg',
  full_name='bess.pb.WorkerSplitArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_gates', full_name='bess.pb.WorkerSplitArg.worker_gates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WORKERSPLITARG_WORKERGATESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6408,
  serialized_end=6540,
)

_EXACTMATCHCOMMANDADDARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELDDATA
_EXACTMATCHCOMMANDDELETEARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELDDATA
_HASHLBCOMMANDSETMODEARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELD
_L2FORWARDCOMMANDADDARG_ENTRY.containing_type = _L2FORWARDCOMMANDADDARG
_L2FORWARDCOMMANDADDARG.fields_by_name['entries'].message_type = _L2FORWARDCOMMANDADDARG_ENTRY
_MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM.containing_type = _MEASURECOMMANDGETSUMMARYRESPONSE
_MEASURECOMMANDGETSUMMARYRESPONSE.fields_by_name['latency'].message_type = _MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM
_MEASURECOMMANDGETSUMMARYRESPONSE.fields_by_name['jitter'].message_type = _MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM
_WILDCARDMATCHCOMMANDADDARG.fields_by_name['values'].message_type = util__msg__pb2._FIELDDATA
_WILDCARDMATCHCOMMANDADDARG.fields_by_name['masks'].message_type = util__msg__pb2._FIELDDATA
_WILDCARDMATCHCOMMANDDELETEARG.fields_by_name['values'].message_type = util__msg__pb2._FIELDDATA
_WILDCARDMATCHCOMMANDDELETEARG.fields_by_name['masks'].message_type = util__msg__pb2._FIELDDATA
_ACLARG_RULE.containing_type = _ACLARG
_ACLARG.fields_by_name['rules'].message_type = _ACLARG_RULE
_BPFARG_FILTER.containing_type = _BPFARG
_BPFARG.fields_by_name['filters'].message_type = _BPFARG_FILTER
_EXACTMATCHARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELD
_EXACTMATCHARG.fields_by_name['masks'].message_type = util__msg__pb2._FIELDDATA
_EXACTMATCHCONFIG.fields_by_name['rules'].message_type = _EXACTMATCHCOMMANDADDARG
_GENERICENCAPARG_ENCAPFIELD.fields_by_name['value'].message_type = util__msg__pb2._FIELDDATA
_GENERICENCAPARG_ENCAPFIELD.containing_type = _GENERICENCAPARG
_GENERICENCAPARG_ENCAPFIELD.oneofs_by_name['insertion'].fields.append(
  _GENERICENCAPARG_ENCAPFIELD.fields_by_name['attribute'])
_GENERICENCAPARG_ENCAPFIELD.fields_by_name['attribute'].containing_oneof = _GENERICENCAPARG_ENCAPFIELD.oneofs_by_name['insertion']
_GENERICENCAPARG_ENCAPFIELD.oneofs_by_name['insertion'].fields.append(
  _GENERICENCAPARG_ENCAPFIELD.fields_by_name['value'])
_GENERICENCAPARG_ENCAPFIELD.fields_by_name['value'].containing_oneof = _GENERICENCAPARG_ENCAPFIELD.oneofs_by_name['insertion']
_GENERICENCAPARG.fields_by_name['fields'].message_type = _GENERICENCAPARG_ENCAPFIELD
_HASHLBARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELD
_METADATATESTARG_READENTRY.containing_type = _METADATATESTARG
_METADATATESTARG_WRITEENTRY.containing_type = _METADATATESTARG
_METADATATESTARG_UPDATEENTRY.containing_type = _METADATATESTARG
_METADATATESTARG.fields_by_name['read'].message_type = _METADATATESTARG_READENTRY
_METADATATESTARG.fields_by_name['write'].message_type = _METADATATESTARG_WRITEENTRY
_METADATATESTARG.fields_by_name['update'].message_type = _METADATATESTARG_UPDATEENTRY
_NATARG_PORTRANGE.containing_type = _NATARG
_NATARG_EXTERNALADDRESS.fields_by_name['port_ranges'].message_type = _NATARG_PORTRANGE
_NATARG_EXTERNALADDRESS.containing_type = _NATARG
_NATARG.fields_by_name['ext_addrs'].message_type = _NATARG_EXTERNALADDRESS
_STATICNATARG_ADDRESSRANGE.containing_type = _STATICNATARG
_STATICNATARG_ADDRESSRANGEPAIR.fields_by_name['int_range'].message_type = _STATICNATARG_ADDRESSRANGE
_STATICNATARG_ADDRESSRANGEPAIR.fields_by_name['ext_range'].message_type = _STATICNATARG_ADDRESSRANGE
_STATICNATARG_ADDRESSRANGEPAIR.containing_type = _STATICNATARG
_STATICNATARG.fields_by_name['pairs'].message_type = _STATICNATARG_ADDRESSRANGEPAIR
_RANDOMUPDATEARG_FIELD.containing_type = _RANDOMUPDATEARG
_RANDOMUPDATEARG.fields_by_name['fields'].message_type = _RANDOMUPDATEARG_FIELD
_SETMETADATAARG_ATTRIBUTE.containing_type = _SETMETADATAARG
_SETMETADATAARG_ATTRIBUTE.oneofs_by_name['value'].fields.append(
  _SETMETADATAARG_ATTRIBUTE.fields_by_name['value_int'])
_SETMETADATAARG_ATTRIBUTE.fields_by_name['value_int'].containing_oneof = _SETMETADATAARG_ATTRIBUTE.oneofs_by_name['value']
_SETMETADATAARG_ATTRIBUTE.oneofs_by_name['value'].fields.append(
  _SETMETADATAARG_ATTRIBUTE.fields_by_name['value_bin'])
_SETMETADATAARG_ATTRIBUTE.fields_by_name['value_bin'].containing_oneof = _SETMETADATAARG_ATTRIBUTE.oneofs_by_name['value']
_SETMETADATAARG.fields_by_name['attrs'].message_type = _SETMETADATAARG_ATTRIBUTE
_SPLITARG.oneofs_by_name['type'].fields.append(
  _SPLITARG.fields_by_name['attribute'])
_SPLITARG.fields_by_name['attribute'].containing_oneof = _SPLITARG.oneofs_by_name['type']
_SPLITARG.oneofs_by_name['type'].fields.append(
  _SPLITARG.fields_by_name['offset'])
_SPLITARG.fields_by_name['offset'].containing_oneof = _SPLITARG.oneofs_by_name['type']
_UPDATEARG_FIELD.containing_type = _UPDATEARG
_UPDATEARG.fields_by_name['fields'].message_type = _UPDATEARG_FIELD
_URLFILTERARG_URL.containing_type = _URLFILTERARG
_URLFILTERARG.fields_by_name['blacklist'].message_type = _URLFILTERARG_URL
_URLFILTERCONFIG.fields_by_name['blacklist'].message_type = _URLFILTERARG_URL
_WILDCARDMATCHARG.fields_by_name['fields'].message_type = util__msg__pb2._FIELD
_WILDCARDMATCHCONFIG.fields_by_name['rules'].message_type = _WILDCARDMATCHCOMMANDADDARG
_WORKERSPLITARG_WORKERGATESENTRY.containing_type = _WORKERSPLITARG
_WORKERSPLITARG.fields_by_name['worker_gates'].message_type = _WORKERSPLITARG_WORKERGATESENTRY
DESCRIPTOR.message_types_by_name['EmptyArg'] = _EMPTYARG
DESCRIPTOR.message_types_by_name['BPFCommandClearArg'] = _BPFCOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['ExactMatchCommandAddArg'] = _EXACTMATCHCOMMANDADDARG
DESCRIPTOR.message_types_by_name['ExactMatchCommandDeleteArg'] = _EXACTMATCHCOMMANDDELETEARG
DESCRIPTOR.message_types_by_name['ExactMatchCommandClearArg'] = _EXACTMATCHCOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['ExactMatchCommandSetDefaultGateArg'] = _EXACTMATCHCOMMANDSETDEFAULTGATEARG
DESCRIPTOR.message_types_by_name['FlowGenCommandSetBurstArg'] = _FLOWGENCOMMANDSETBURSTARG
DESCRIPTOR.message_types_by_name['HashLBCommandSetModeArg'] = _HASHLBCOMMANDSETMODEARG
DESCRIPTOR.message_types_by_name['HashLBCommandSetGatesArg'] = _HASHLBCOMMANDSETGATESARG
DESCRIPTOR.message_types_by_name['IPLookupCommandAddArg'] = _IPLOOKUPCOMMANDADDARG
DESCRIPTOR.message_types_by_name['IPLookupCommandDeleteArg'] = _IPLOOKUPCOMMANDDELETEARG
DESCRIPTOR.message_types_by_name['IPLookupCommandClearArg'] = _IPLOOKUPCOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['L2ForwardCommandAddArg'] = _L2FORWARDCOMMANDADDARG
DESCRIPTOR.message_types_by_name['L2ForwardCommandDeleteArg'] = _L2FORWARDCOMMANDDELETEARG
DESCRIPTOR.message_types_by_name['L2ForwardCommandSetDefaultGateArg'] = _L2FORWARDCOMMANDSETDEFAULTGATEARG
DESCRIPTOR.message_types_by_name['L2ForwardCommandLookupArg'] = _L2FORWARDCOMMANDLOOKUPARG
DESCRIPTOR.message_types_by_name['L2ForwardCommandLookupResponse'] = _L2FORWARDCOMMANDLOOKUPRESPONSE
DESCRIPTOR.message_types_by_name['L2ForwardCommandPopulateArg'] = _L2FORWARDCOMMANDPOPULATEARG
DESCRIPTOR.message_types_by_name['MeasureCommandGetSummaryArg'] = _MEASURECOMMANDGETSUMMARYARG
DESCRIPTOR.message_types_by_name['MeasureCommandGetSummaryResponse'] = _MEASURECOMMANDGETSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['DRRArg'] = _DRRARG
DESCRIPTOR.message_types_by_name['DRRQuantumArg'] = _DRRQUANTUMARG
DESCRIPTOR.message_types_by_name['DRRMaxFlowQueueSizeArg'] = _DRRMAXFLOWQUEUESIZEARG
DESCRIPTOR.message_types_by_name['PortIncCommandSetBurstArg'] = _PORTINCCOMMANDSETBURSTARG
DESCRIPTOR.message_types_by_name['QueueIncCommandSetBurstArg'] = _QUEUEINCCOMMANDSETBURSTARG
DESCRIPTOR.message_types_by_name['QueueCommandSetBurstArg'] = _QUEUECOMMANDSETBURSTARG
DESCRIPTOR.message_types_by_name['QueueCommandSetSizeArg'] = _QUEUECOMMANDSETSIZEARG
DESCRIPTOR.message_types_by_name['QueueCommandGetStatusArg'] = _QUEUECOMMANDGETSTATUSARG
DESCRIPTOR.message_types_by_name['QueueCommandGetStatusResponse'] = _QUEUECOMMANDGETSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['RandomUpdateCommandClearArg'] = _RANDOMUPDATECOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['RewriteCommandClearArg'] = _REWRITECOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['UpdateCommandClearArg'] = _UPDATECOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['WildcardMatchCommandAddArg'] = _WILDCARDMATCHCOMMANDADDARG
DESCRIPTOR.message_types_by_name['WildcardMatchCommandDeleteArg'] = _WILDCARDMATCHCOMMANDDELETEARG
DESCRIPTOR.message_types_by_name['WildcardMatchCommandClearArg'] = _WILDCARDMATCHCOMMANDCLEARARG
DESCRIPTOR.message_types_by_name['WildcardMatchCommandSetDefaultGateArg'] = _WILDCARDMATCHCOMMANDSETDEFAULTGATEARG
DESCRIPTOR.message_types_by_name['ACLArg'] = _ACLARG
DESCRIPTOR.message_types_by_name['BPFArg'] = _BPFARG
DESCRIPTOR.message_types_by_name['BufferArg'] = _BUFFERARG
DESCRIPTOR.message_types_by_name['BypassArg'] = _BYPASSARG
DESCRIPTOR.message_types_by_name['DumpArg'] = _DUMPARG
DESCRIPTOR.message_types_by_name['EtherEncapArg'] = _ETHERENCAPARG
DESCRIPTOR.message_types_by_name['ExactMatchArg'] = _EXACTMATCHARG
DESCRIPTOR.message_types_by_name['ExactMatchConfig'] = _EXACTMATCHCONFIG
DESCRIPTOR.message_types_by_name['FlowGenArg'] = _FLOWGENARG
DESCRIPTOR.message_types_by_name['GenericDecapArg'] = _GENERICDECAPARG
DESCRIPTOR.message_types_by_name['GenericEncapArg'] = _GENERICENCAPARG
DESCRIPTOR.message_types_by_name['HashLBArg'] = _HASHLBARG
DESCRIPTOR.message_types_by_name['IPEncapArg'] = _IPENCAPARG
DESCRIPTOR.message_types_by_name['IPLookupArg'] = _IPLOOKUPARG
DESCRIPTOR.message_types_by_name['L2ForwardArg'] = _L2FORWARDARG
DESCRIPTOR.message_types_by_name['MACSwapArg'] = _MACSWAPARG
DESCRIPTOR.message_types_by_name['MeasureArg'] = _MEASUREARG
DESCRIPTOR.message_types_by_name['MergeArg'] = _MERGEARG
DESCRIPTOR.message_types_by_name['MetadataTestArg'] = _METADATATESTARG
DESCRIPTOR.message_types_by_name['NATArg'] = _NATARG
DESCRIPTOR.message_types_by_name['StaticNATArg'] = _STATICNATARG
DESCRIPTOR.message_types_by_name['NoOpArg'] = _NOOPARG
DESCRIPTOR.message_types_by_name['PortIncArg'] = _PORTINCARG
DESCRIPTOR.message_types_by_name['PortOutArg'] = _PORTOUTARG
DESCRIPTOR.message_types_by_name['QueueIncArg'] = _QUEUEINCARG
DESCRIPTOR.message_types_by_name['QueueOutArg'] = _QUEUEOUTARG
DESCRIPTOR.message_types_by_name['QueueArg'] = _QUEUEARG
DESCRIPTOR.message_types_by_name['RandomSplitArg'] = _RANDOMSPLITARG
DESCRIPTOR.message_types_by_name['RandomSplitCommandSetDroprateArg'] = _RANDOMSPLITCOMMANDSETDROPRATEARG
DESCRIPTOR.message_types_by_name['RandomSplitCommandSetGatesArg'] = _RANDOMSPLITCOMMANDSETGATESARG
DESCRIPTOR.message_types_by_name['RandomUpdateArg'] = _RANDOMUPDATEARG
DESCRIPTOR.message_types_by_name['RewriteArg'] = _REWRITEARG
DESCRIPTOR.message_types_by_name['RoundRobinCommandSetGatesArg'] = _ROUNDROBINCOMMANDSETGATESARG
DESCRIPTOR.message_types_by_name['RoundRobinCommandSetModeArg'] = _ROUNDROBINCOMMANDSETMODEARG
DESCRIPTOR.message_types_by_name['RoundRobinArg'] = _ROUNDROBINARG
DESCRIPTOR.message_types_by_name['ReplicateArg'] = _REPLICATEARG
DESCRIPTOR.message_types_by_name['ReplicateCommandSetGatesArg'] = _REPLICATECOMMANDSETGATESARG
DESCRIPTOR.message_types_by_name['SetMetadataArg'] = _SETMETADATAARG
DESCRIPTOR.message_types_by_name['SinkArg'] = _SINKARG
DESCRIPTOR.message_types_by_name['SourceCommandSetBurstArg'] = _SOURCECOMMANDSETBURSTARG
DESCRIPTOR.message_types_by_name['SourceCommandSetPktSizeArg'] = _SOURCECOMMANDSETPKTSIZEARG
DESCRIPTOR.message_types_by_name['SourceArg'] = _SOURCEARG
DESCRIPTOR.message_types_by_name['SplitArg'] = _SPLITARG
DESCRIPTOR.message_types_by_name['TimestampArg'] = _TIMESTAMPARG
DESCRIPTOR.message_types_by_name['UpdateArg'] = _UPDATEARG
DESCRIPTOR.message_types_by_name['UrlFilterArg'] = _URLFILTERARG
DESCRIPTOR.message_types_by_name['UrlFilterConfig'] = _URLFILTERCONFIG
DESCRIPTOR.message_types_by_name['VLANPopArg'] = _VLANPOPARG
DESCRIPTOR.message_types_by_name['VLANPushArg'] = _VLANPUSHARG
DESCRIPTOR.message_types_by_name['VLANSplitArg'] = _VLANSPLITARG
DESCRIPTOR.message_types_by_name['VXLANDecapArg'] = _VXLANDECAPARG
DESCRIPTOR.message_types_by_name['VXLANEncapArg'] = _VXLANENCAPARG
DESCRIPTOR.message_types_by_name['WildcardMatchArg'] = _WILDCARDMATCHARG
DESCRIPTOR.message_types_by_name['WildcardMatchConfig'] = _WILDCARDMATCHCONFIG
DESCRIPTOR.message_types_by_name['ArpResponderArg'] = _ARPRESPONDERARG
DESCRIPTOR.message_types_by_name['MplsPopArg'] = _MPLSPOPARG
DESCRIPTOR.message_types_by_name['WorkerSplitArg'] = _WORKERSPLITARG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmptyArg = _reflection.GeneratedProtocolMessageType('EmptyArg', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.EmptyArg)
  })
_sym_db.RegisterMessage(EmptyArg)

BPFCommandClearArg = _reflection.GeneratedProtocolMessageType('BPFCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _BPFCOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.BPFCommandClearArg)
  })
_sym_db.RegisterMessage(BPFCommandClearArg)

ExactMatchCommandAddArg = _reflection.GeneratedProtocolMessageType('ExactMatchCommandAddArg', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHCOMMANDADDARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchCommandAddArg)
  })
_sym_db.RegisterMessage(ExactMatchCommandAddArg)

ExactMatchCommandDeleteArg = _reflection.GeneratedProtocolMessageType('ExactMatchCommandDeleteArg', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHCOMMANDDELETEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchCommandDeleteArg)
  })
_sym_db.RegisterMessage(ExactMatchCommandDeleteArg)

ExactMatchCommandClearArg = _reflection.GeneratedProtocolMessageType('ExactMatchCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHCOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchCommandClearArg)
  })
_sym_db.RegisterMessage(ExactMatchCommandClearArg)

ExactMatchCommandSetDefaultGateArg = _reflection.GeneratedProtocolMessageType('ExactMatchCommandSetDefaultGateArg', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHCOMMANDSETDEFAULTGATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchCommandSetDefaultGateArg)
  })
_sym_db.RegisterMessage(ExactMatchCommandSetDefaultGateArg)

FlowGenCommandSetBurstArg = _reflection.GeneratedProtocolMessageType('FlowGenCommandSetBurstArg', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGENCOMMANDSETBURSTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.FlowGenCommandSetBurstArg)
  })
_sym_db.RegisterMessage(FlowGenCommandSetBurstArg)

HashLBCommandSetModeArg = _reflection.GeneratedProtocolMessageType('HashLBCommandSetModeArg', (_message.Message,), {
  'DESCRIPTOR' : _HASHLBCOMMANDSETMODEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.HashLBCommandSetModeArg)
  })
_sym_db.RegisterMessage(HashLBCommandSetModeArg)

HashLBCommandSetGatesArg = _reflection.GeneratedProtocolMessageType('HashLBCommandSetGatesArg', (_message.Message,), {
  'DESCRIPTOR' : _HASHLBCOMMANDSETGATESARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.HashLBCommandSetGatesArg)
  })
_sym_db.RegisterMessage(HashLBCommandSetGatesArg)

IPLookupCommandAddArg = _reflection.GeneratedProtocolMessageType('IPLookupCommandAddArg', (_message.Message,), {
  'DESCRIPTOR' : _IPLOOKUPCOMMANDADDARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.IPLookupCommandAddArg)
  })
_sym_db.RegisterMessage(IPLookupCommandAddArg)

IPLookupCommandDeleteArg = _reflection.GeneratedProtocolMessageType('IPLookupCommandDeleteArg', (_message.Message,), {
  'DESCRIPTOR' : _IPLOOKUPCOMMANDDELETEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.IPLookupCommandDeleteArg)
  })
_sym_db.RegisterMessage(IPLookupCommandDeleteArg)

IPLookupCommandClearArg = _reflection.GeneratedProtocolMessageType('IPLookupCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _IPLOOKUPCOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.IPLookupCommandClearArg)
  })
_sym_db.RegisterMessage(IPLookupCommandClearArg)

L2ForwardCommandAddArg = _reflection.GeneratedProtocolMessageType('L2ForwardCommandAddArg', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _L2FORWARDCOMMANDADDARG_ENTRY,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandAddArg.Entry)
    })
  ,
  'DESCRIPTOR' : _L2FORWARDCOMMANDADDARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandAddArg)
  })
_sym_db.RegisterMessage(L2ForwardCommandAddArg)
_sym_db.RegisterMessage(L2ForwardCommandAddArg.Entry)

L2ForwardCommandDeleteArg = _reflection.GeneratedProtocolMessageType('L2ForwardCommandDeleteArg', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDCOMMANDDELETEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandDeleteArg)
  })
_sym_db.RegisterMessage(L2ForwardCommandDeleteArg)

L2ForwardCommandSetDefaultGateArg = _reflection.GeneratedProtocolMessageType('L2ForwardCommandSetDefaultGateArg', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDCOMMANDSETDEFAULTGATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandSetDefaultGateArg)
  })
_sym_db.RegisterMessage(L2ForwardCommandSetDefaultGateArg)

L2ForwardCommandLookupArg = _reflection.GeneratedProtocolMessageType('L2ForwardCommandLookupArg', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDCOMMANDLOOKUPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandLookupArg)
  })
_sym_db.RegisterMessage(L2ForwardCommandLookupArg)

L2ForwardCommandLookupResponse = _reflection.GeneratedProtocolMessageType('L2ForwardCommandLookupResponse', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDCOMMANDLOOKUPRESPONSE,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandLookupResponse)
  })
_sym_db.RegisterMessage(L2ForwardCommandLookupResponse)

L2ForwardCommandPopulateArg = _reflection.GeneratedProtocolMessageType('L2ForwardCommandPopulateArg', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDCOMMANDPOPULATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardCommandPopulateArg)
  })
_sym_db.RegisterMessage(L2ForwardCommandPopulateArg)

MeasureCommandGetSummaryArg = _reflection.GeneratedProtocolMessageType('MeasureCommandGetSummaryArg', (_message.Message,), {
  'DESCRIPTOR' : _MEASURECOMMANDGETSUMMARYARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MeasureCommandGetSummaryArg)
  })
_sym_db.RegisterMessage(MeasureCommandGetSummaryArg)

MeasureCommandGetSummaryResponse = _reflection.GeneratedProtocolMessageType('MeasureCommandGetSummaryResponse', (_message.Message,), {

  'Histogram' : _reflection.GeneratedProtocolMessageType('Histogram', (_message.Message,), {
    'DESCRIPTOR' : _MEASURECOMMANDGETSUMMARYRESPONSE_HISTOGRAM,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.MeasureCommandGetSummaryResponse.Histogram)
    })
  ,
  'DESCRIPTOR' : _MEASURECOMMANDGETSUMMARYRESPONSE,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MeasureCommandGetSummaryResponse)
  })
_sym_db.RegisterMessage(MeasureCommandGetSummaryResponse)
_sym_db.RegisterMessage(MeasureCommandGetSummaryResponse.Histogram)

DRRArg = _reflection.GeneratedProtocolMessageType('DRRArg', (_message.Message,), {
  'DESCRIPTOR' : _DRRARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DRRArg)
  })
_sym_db.RegisterMessage(DRRArg)

DRRQuantumArg = _reflection.GeneratedProtocolMessageType('DRRQuantumArg', (_message.Message,), {
  'DESCRIPTOR' : _DRRQUANTUMARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DRRQuantumArg)
  })
_sym_db.RegisterMessage(DRRQuantumArg)

DRRMaxFlowQueueSizeArg = _reflection.GeneratedProtocolMessageType('DRRMaxFlowQueueSizeArg', (_message.Message,), {
  'DESCRIPTOR' : _DRRMAXFLOWQUEUESIZEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DRRMaxFlowQueueSizeArg)
  })
_sym_db.RegisterMessage(DRRMaxFlowQueueSizeArg)

PortIncCommandSetBurstArg = _reflection.GeneratedProtocolMessageType('PortIncCommandSetBurstArg', (_message.Message,), {
  'DESCRIPTOR' : _PORTINCCOMMANDSETBURSTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PortIncCommandSetBurstArg)
  })
_sym_db.RegisterMessage(PortIncCommandSetBurstArg)

QueueIncCommandSetBurstArg = _reflection.GeneratedProtocolMessageType('QueueIncCommandSetBurstArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEINCCOMMANDSETBURSTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueIncCommandSetBurstArg)
  })
_sym_db.RegisterMessage(QueueIncCommandSetBurstArg)

QueueCommandSetBurstArg = _reflection.GeneratedProtocolMessageType('QueueCommandSetBurstArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUECOMMANDSETBURSTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueCommandSetBurstArg)
  })
_sym_db.RegisterMessage(QueueCommandSetBurstArg)

QueueCommandSetSizeArg = _reflection.GeneratedProtocolMessageType('QueueCommandSetSizeArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUECOMMANDSETSIZEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueCommandSetSizeArg)
  })
_sym_db.RegisterMessage(QueueCommandSetSizeArg)

QueueCommandGetStatusArg = _reflection.GeneratedProtocolMessageType('QueueCommandGetStatusArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUECOMMANDGETSTATUSARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueCommandGetStatusArg)
  })
_sym_db.RegisterMessage(QueueCommandGetStatusArg)

QueueCommandGetStatusResponse = _reflection.GeneratedProtocolMessageType('QueueCommandGetStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUECOMMANDGETSTATUSRESPONSE,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueCommandGetStatusResponse)
  })
_sym_db.RegisterMessage(QueueCommandGetStatusResponse)

RandomUpdateCommandClearArg = _reflection.GeneratedProtocolMessageType('RandomUpdateCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMUPDATECOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RandomUpdateCommandClearArg)
  })
_sym_db.RegisterMessage(RandomUpdateCommandClearArg)

RewriteCommandClearArg = _reflection.GeneratedProtocolMessageType('RewriteCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _REWRITECOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RewriteCommandClearArg)
  })
_sym_db.RegisterMessage(RewriteCommandClearArg)

UpdateCommandClearArg = _reflection.GeneratedProtocolMessageType('UpdateCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UpdateCommandClearArg)
  })
_sym_db.RegisterMessage(UpdateCommandClearArg)

WildcardMatchCommandAddArg = _reflection.GeneratedProtocolMessageType('WildcardMatchCommandAddArg', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHCOMMANDADDARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchCommandAddArg)
  })
_sym_db.RegisterMessage(WildcardMatchCommandAddArg)

WildcardMatchCommandDeleteArg = _reflection.GeneratedProtocolMessageType('WildcardMatchCommandDeleteArg', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHCOMMANDDELETEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchCommandDeleteArg)
  })
_sym_db.RegisterMessage(WildcardMatchCommandDeleteArg)

WildcardMatchCommandClearArg = _reflection.GeneratedProtocolMessageType('WildcardMatchCommandClearArg', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHCOMMANDCLEARARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchCommandClearArg)
  })
_sym_db.RegisterMessage(WildcardMatchCommandClearArg)

WildcardMatchCommandSetDefaultGateArg = _reflection.GeneratedProtocolMessageType('WildcardMatchCommandSetDefaultGateArg', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHCOMMANDSETDEFAULTGATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchCommandSetDefaultGateArg)
  })
_sym_db.RegisterMessage(WildcardMatchCommandSetDefaultGateArg)

ACLArg = _reflection.GeneratedProtocolMessageType('ACLArg', (_message.Message,), {

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _ACLARG_RULE,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.ACLArg.Rule)
    })
  ,
  'DESCRIPTOR' : _ACLARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ACLArg)
  })
_sym_db.RegisterMessage(ACLArg)
_sym_db.RegisterMessage(ACLArg.Rule)

BPFArg = _reflection.GeneratedProtocolMessageType('BPFArg', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _BPFARG_FILTER,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.BPFArg.Filter)
    })
  ,
  'DESCRIPTOR' : _BPFARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.BPFArg)
  })
_sym_db.RegisterMessage(BPFArg)
_sym_db.RegisterMessage(BPFArg.Filter)

BufferArg = _reflection.GeneratedProtocolMessageType('BufferArg', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.BufferArg)
  })
_sym_db.RegisterMessage(BufferArg)

BypassArg = _reflection.GeneratedProtocolMessageType('BypassArg', (_message.Message,), {
  'DESCRIPTOR' : _BYPASSARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.BypassArg)
  })
_sym_db.RegisterMessage(BypassArg)

DumpArg = _reflection.GeneratedProtocolMessageType('DumpArg', (_message.Message,), {
  'DESCRIPTOR' : _DUMPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.DumpArg)
  })
_sym_db.RegisterMessage(DumpArg)

EtherEncapArg = _reflection.GeneratedProtocolMessageType('EtherEncapArg', (_message.Message,), {
  'DESCRIPTOR' : _ETHERENCAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.EtherEncapArg)
  })
_sym_db.RegisterMessage(EtherEncapArg)

ExactMatchArg = _reflection.GeneratedProtocolMessageType('ExactMatchArg', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchArg)
  })
_sym_db.RegisterMessage(ExactMatchArg)

ExactMatchConfig = _reflection.GeneratedProtocolMessageType('ExactMatchConfig', (_message.Message,), {
  'DESCRIPTOR' : _EXACTMATCHCONFIG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ExactMatchConfig)
  })
_sym_db.RegisterMessage(ExactMatchConfig)

FlowGenArg = _reflection.GeneratedProtocolMessageType('FlowGenArg', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGENARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.FlowGenArg)
  })
_sym_db.RegisterMessage(FlowGenArg)

GenericDecapArg = _reflection.GeneratedProtocolMessageType('GenericDecapArg', (_message.Message,), {
  'DESCRIPTOR' : _GENERICDECAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GenericDecapArg)
  })
_sym_db.RegisterMessage(GenericDecapArg)

GenericEncapArg = _reflection.GeneratedProtocolMessageType('GenericEncapArg', (_message.Message,), {

  'EncapField' : _reflection.GeneratedProtocolMessageType('EncapField', (_message.Message,), {
    'DESCRIPTOR' : _GENERICENCAPARG_ENCAPFIELD,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.GenericEncapArg.EncapField)
    })
  ,
  'DESCRIPTOR' : _GENERICENCAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.GenericEncapArg)
  })
_sym_db.RegisterMessage(GenericEncapArg)
_sym_db.RegisterMessage(GenericEncapArg.EncapField)

HashLBArg = _reflection.GeneratedProtocolMessageType('HashLBArg', (_message.Message,), {
  'DESCRIPTOR' : _HASHLBARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.HashLBArg)
  })
_sym_db.RegisterMessage(HashLBArg)

IPEncapArg = _reflection.GeneratedProtocolMessageType('IPEncapArg', (_message.Message,), {
  'DESCRIPTOR' : _IPENCAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.IPEncapArg)
  })
_sym_db.RegisterMessage(IPEncapArg)

IPLookupArg = _reflection.GeneratedProtocolMessageType('IPLookupArg', (_message.Message,), {
  'DESCRIPTOR' : _IPLOOKUPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.IPLookupArg)
  })
_sym_db.RegisterMessage(IPLookupArg)

L2ForwardArg = _reflection.GeneratedProtocolMessageType('L2ForwardArg', (_message.Message,), {
  'DESCRIPTOR' : _L2FORWARDARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.L2ForwardArg)
  })
_sym_db.RegisterMessage(L2ForwardArg)

MACSwapArg = _reflection.GeneratedProtocolMessageType('MACSwapArg', (_message.Message,), {
  'DESCRIPTOR' : _MACSWAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MACSwapArg)
  })
_sym_db.RegisterMessage(MACSwapArg)

MeasureArg = _reflection.GeneratedProtocolMessageType('MeasureArg', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MeasureArg)
  })
_sym_db.RegisterMessage(MeasureArg)

MergeArg = _reflection.GeneratedProtocolMessageType('MergeArg', (_message.Message,), {
  'DESCRIPTOR' : _MERGEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MergeArg)
  })
_sym_db.RegisterMessage(MergeArg)

MetadataTestArg = _reflection.GeneratedProtocolMessageType('MetadataTestArg', (_message.Message,), {

  'ReadEntry' : _reflection.GeneratedProtocolMessageType('ReadEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATATESTARG_READENTRY,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.MetadataTestArg.ReadEntry)
    })
  ,

  'WriteEntry' : _reflection.GeneratedProtocolMessageType('WriteEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATATESTARG_WRITEENTRY,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.MetadataTestArg.WriteEntry)
    })
  ,

  'UpdateEntry' : _reflection.GeneratedProtocolMessageType('UpdateEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATATESTARG_UPDATEENTRY,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.MetadataTestArg.UpdateEntry)
    })
  ,
  'DESCRIPTOR' : _METADATATESTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MetadataTestArg)
  })
_sym_db.RegisterMessage(MetadataTestArg)
_sym_db.RegisterMessage(MetadataTestArg.ReadEntry)
_sym_db.RegisterMessage(MetadataTestArg.WriteEntry)
_sym_db.RegisterMessage(MetadataTestArg.UpdateEntry)

NATArg = _reflection.GeneratedProtocolMessageType('NATArg', (_message.Message,), {

  'PortRange' : _reflection.GeneratedProtocolMessageType('PortRange', (_message.Message,), {
    'DESCRIPTOR' : _NATARG_PORTRANGE,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.NATArg.PortRange)
    })
  ,

  'ExternalAddress' : _reflection.GeneratedProtocolMessageType('ExternalAddress', (_message.Message,), {
    'DESCRIPTOR' : _NATARG_EXTERNALADDRESS,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.NATArg.ExternalAddress)
    })
  ,
  'DESCRIPTOR' : _NATARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.NATArg)
  })
_sym_db.RegisterMessage(NATArg)
_sym_db.RegisterMessage(NATArg.PortRange)
_sym_db.RegisterMessage(NATArg.ExternalAddress)

StaticNATArg = _reflection.GeneratedProtocolMessageType('StaticNATArg', (_message.Message,), {

  'AddressRange' : _reflection.GeneratedProtocolMessageType('AddressRange', (_message.Message,), {
    'DESCRIPTOR' : _STATICNATARG_ADDRESSRANGE,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.StaticNATArg.AddressRange)
    })
  ,

  'AddressRangePair' : _reflection.GeneratedProtocolMessageType('AddressRangePair', (_message.Message,), {
    'DESCRIPTOR' : _STATICNATARG_ADDRESSRANGEPAIR,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.StaticNATArg.AddressRangePair)
    })
  ,
  'DESCRIPTOR' : _STATICNATARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.StaticNATArg)
  })
_sym_db.RegisterMessage(StaticNATArg)
_sym_db.RegisterMessage(StaticNATArg.AddressRange)
_sym_db.RegisterMessage(StaticNATArg.AddressRangePair)

NoOpArg = _reflection.GeneratedProtocolMessageType('NoOpArg', (_message.Message,), {
  'DESCRIPTOR' : _NOOPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.NoOpArg)
  })
_sym_db.RegisterMessage(NoOpArg)

PortIncArg = _reflection.GeneratedProtocolMessageType('PortIncArg', (_message.Message,), {
  'DESCRIPTOR' : _PORTINCARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PortIncArg)
  })
_sym_db.RegisterMessage(PortIncArg)

PortOutArg = _reflection.GeneratedProtocolMessageType('PortOutArg', (_message.Message,), {
  'DESCRIPTOR' : _PORTOUTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.PortOutArg)
  })
_sym_db.RegisterMessage(PortOutArg)

QueueIncArg = _reflection.GeneratedProtocolMessageType('QueueIncArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEINCARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueIncArg)
  })
_sym_db.RegisterMessage(QueueIncArg)

QueueOutArg = _reflection.GeneratedProtocolMessageType('QueueOutArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEOUTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueOutArg)
  })
_sym_db.RegisterMessage(QueueOutArg)

QueueArg = _reflection.GeneratedProtocolMessageType('QueueArg', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.QueueArg)
  })
_sym_db.RegisterMessage(QueueArg)

RandomSplitArg = _reflection.GeneratedProtocolMessageType('RandomSplitArg', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMSPLITARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RandomSplitArg)
  })
_sym_db.RegisterMessage(RandomSplitArg)

RandomSplitCommandSetDroprateArg = _reflection.GeneratedProtocolMessageType('RandomSplitCommandSetDroprateArg', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMSPLITCOMMANDSETDROPRATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RandomSplitCommandSetDroprateArg)
  })
_sym_db.RegisterMessage(RandomSplitCommandSetDroprateArg)

RandomSplitCommandSetGatesArg = _reflection.GeneratedProtocolMessageType('RandomSplitCommandSetGatesArg', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMSPLITCOMMANDSETGATESARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RandomSplitCommandSetGatesArg)
  })
_sym_db.RegisterMessage(RandomSplitCommandSetGatesArg)

RandomUpdateArg = _reflection.GeneratedProtocolMessageType('RandomUpdateArg', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _RANDOMUPDATEARG_FIELD,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.RandomUpdateArg.Field)
    })
  ,
  'DESCRIPTOR' : _RANDOMUPDATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RandomUpdateArg)
  })
_sym_db.RegisterMessage(RandomUpdateArg)
_sym_db.RegisterMessage(RandomUpdateArg.Field)

RewriteArg = _reflection.GeneratedProtocolMessageType('RewriteArg', (_message.Message,), {
  'DESCRIPTOR' : _REWRITEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RewriteArg)
  })
_sym_db.RegisterMessage(RewriteArg)

RoundRobinCommandSetGatesArg = _reflection.GeneratedProtocolMessageType('RoundRobinCommandSetGatesArg', (_message.Message,), {
  'DESCRIPTOR' : _ROUNDROBINCOMMANDSETGATESARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RoundRobinCommandSetGatesArg)
  })
_sym_db.RegisterMessage(RoundRobinCommandSetGatesArg)

RoundRobinCommandSetModeArg = _reflection.GeneratedProtocolMessageType('RoundRobinCommandSetModeArg', (_message.Message,), {
  'DESCRIPTOR' : _ROUNDROBINCOMMANDSETMODEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RoundRobinCommandSetModeArg)
  })
_sym_db.RegisterMessage(RoundRobinCommandSetModeArg)

RoundRobinArg = _reflection.GeneratedProtocolMessageType('RoundRobinArg', (_message.Message,), {
  'DESCRIPTOR' : _ROUNDROBINARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.RoundRobinArg)
  })
_sym_db.RegisterMessage(RoundRobinArg)

ReplicateArg = _reflection.GeneratedProtocolMessageType('ReplicateArg', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ReplicateArg)
  })
_sym_db.RegisterMessage(ReplicateArg)

ReplicateCommandSetGatesArg = _reflection.GeneratedProtocolMessageType('ReplicateCommandSetGatesArg', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATECOMMANDSETGATESARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ReplicateCommandSetGatesArg)
  })
_sym_db.RegisterMessage(ReplicateCommandSetGatesArg)

SetMetadataArg = _reflection.GeneratedProtocolMessageType('SetMetadataArg', (_message.Message,), {

  'Attribute' : _reflection.GeneratedProtocolMessageType('Attribute', (_message.Message,), {
    'DESCRIPTOR' : _SETMETADATAARG_ATTRIBUTE,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.SetMetadataArg.Attribute)
    })
  ,
  'DESCRIPTOR' : _SETMETADATAARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SetMetadataArg)
  })
_sym_db.RegisterMessage(SetMetadataArg)
_sym_db.RegisterMessage(SetMetadataArg.Attribute)

SinkArg = _reflection.GeneratedProtocolMessageType('SinkArg', (_message.Message,), {
  'DESCRIPTOR' : _SINKARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SinkArg)
  })
_sym_db.RegisterMessage(SinkArg)

SourceCommandSetBurstArg = _reflection.GeneratedProtocolMessageType('SourceCommandSetBurstArg', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECOMMANDSETBURSTARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SourceCommandSetBurstArg)
  })
_sym_db.RegisterMessage(SourceCommandSetBurstArg)

SourceCommandSetPktSizeArg = _reflection.GeneratedProtocolMessageType('SourceCommandSetPktSizeArg', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECOMMANDSETPKTSIZEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SourceCommandSetPktSizeArg)
  })
_sym_db.RegisterMessage(SourceCommandSetPktSizeArg)

SourceArg = _reflection.GeneratedProtocolMessageType('SourceArg', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SourceArg)
  })
_sym_db.RegisterMessage(SourceArg)

SplitArg = _reflection.GeneratedProtocolMessageType('SplitArg', (_message.Message,), {
  'DESCRIPTOR' : _SPLITARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.SplitArg)
  })
_sym_db.RegisterMessage(SplitArg)

TimestampArg = _reflection.GeneratedProtocolMessageType('TimestampArg', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.TimestampArg)
  })
_sym_db.RegisterMessage(TimestampArg)

UpdateArg = _reflection.GeneratedProtocolMessageType('UpdateArg', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEARG_FIELD,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.UpdateArg.Field)
    })
  ,
  'DESCRIPTOR' : _UPDATEARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UpdateArg)
  })
_sym_db.RegisterMessage(UpdateArg)
_sym_db.RegisterMessage(UpdateArg.Field)

UrlFilterArg = _reflection.GeneratedProtocolMessageType('UrlFilterArg', (_message.Message,), {

  'Url' : _reflection.GeneratedProtocolMessageType('Url', (_message.Message,), {
    'DESCRIPTOR' : _URLFILTERARG_URL,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.UrlFilterArg.Url)
    })
  ,
  'DESCRIPTOR' : _URLFILTERARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UrlFilterArg)
  })
_sym_db.RegisterMessage(UrlFilterArg)
_sym_db.RegisterMessage(UrlFilterArg.Url)

UrlFilterConfig = _reflection.GeneratedProtocolMessageType('UrlFilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _URLFILTERCONFIG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.UrlFilterConfig)
  })
_sym_db.RegisterMessage(UrlFilterConfig)

VLANPopArg = _reflection.GeneratedProtocolMessageType('VLANPopArg', (_message.Message,), {
  'DESCRIPTOR' : _VLANPOPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VLANPopArg)
  })
_sym_db.RegisterMessage(VLANPopArg)

VLANPushArg = _reflection.GeneratedProtocolMessageType('VLANPushArg', (_message.Message,), {
  'DESCRIPTOR' : _VLANPUSHARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VLANPushArg)
  })
_sym_db.RegisterMessage(VLANPushArg)

VLANSplitArg = _reflection.GeneratedProtocolMessageType('VLANSplitArg', (_message.Message,), {
  'DESCRIPTOR' : _VLANSPLITARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VLANSplitArg)
  })
_sym_db.RegisterMessage(VLANSplitArg)

VXLANDecapArg = _reflection.GeneratedProtocolMessageType('VXLANDecapArg', (_message.Message,), {
  'DESCRIPTOR' : _VXLANDECAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VXLANDecapArg)
  })
_sym_db.RegisterMessage(VXLANDecapArg)

VXLANEncapArg = _reflection.GeneratedProtocolMessageType('VXLANEncapArg', (_message.Message,), {
  'DESCRIPTOR' : _VXLANENCAPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.VXLANEncapArg)
  })
_sym_db.RegisterMessage(VXLANEncapArg)

WildcardMatchArg = _reflection.GeneratedProtocolMessageType('WildcardMatchArg', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchArg)
  })
_sym_db.RegisterMessage(WildcardMatchArg)

WildcardMatchConfig = _reflection.GeneratedProtocolMessageType('WildcardMatchConfig', (_message.Message,), {
  'DESCRIPTOR' : _WILDCARDMATCHCONFIG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WildcardMatchConfig)
  })
_sym_db.RegisterMessage(WildcardMatchConfig)

ArpResponderArg = _reflection.GeneratedProtocolMessageType('ArpResponderArg', (_message.Message,), {
  'DESCRIPTOR' : _ARPRESPONDERARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.ArpResponderArg)
  })
_sym_db.RegisterMessage(ArpResponderArg)

MplsPopArg = _reflection.GeneratedProtocolMessageType('MplsPopArg', (_message.Message,), {
  'DESCRIPTOR' : _MPLSPOPARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.MplsPopArg)
  })
_sym_db.RegisterMessage(MplsPopArg)

WorkerSplitArg = _reflection.GeneratedProtocolMessageType('WorkerSplitArg', (_message.Message,), {

  'WorkerGatesEntry' : _reflection.GeneratedProtocolMessageType('WorkerGatesEntry', (_message.Message,), {
    'DESCRIPTOR' : _WORKERSPLITARG_WORKERGATESENTRY,
    '__module__' : 'module_msg_pb2'
    # @@protoc_insertion_point(class_scope:bess.pb.WorkerSplitArg.WorkerGatesEntry)
    })
  ,
  'DESCRIPTOR' : _WORKERSPLITARG,
  '__module__' : 'module_msg_pb2'
  # @@protoc_insertion_point(class_scope:bess.pb.WorkerSplitArg)
  })
_sym_db.RegisterMessage(WorkerSplitArg)
_sym_db.RegisterMessage(WorkerSplitArg.WorkerGatesEntry)


_METADATATESTARG_READENTRY._options = None
_METADATATESTARG_WRITEENTRY._options = None
_METADATATESTARG_UPDATEENTRY._options = None
_WORKERSPLITARG_WORKERGATESENTRY._options = None
# @@protoc_insertion_point(module_scope)
